@@ -25,7 +25,7 @@ consoleHandler = logging.StreamHandler(stream=sys.stdout)
 consoleHandler.setLevel(logging.INFO)
 
 logger.addHandler(consoleHandler)
-formatter = logging.Formatter('%(asctime)s  %(name)s.%(funcName)s  %(levelname)s: %(message)s',
+formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s  %(levelname)s: %(message)s',
                               datefmt='%Y-%m-%dT%H:%M:%S')
 consoleHandler.setFormatter(formatter)
 
@@ -185,7 +185,7 @@ def get_sites(api_inputs: ApiInputs, include_tag_groups: Union[list, bool] = Fal
         tags_mode = include_tag_groups
 
     payload = {
-        "sendAllTags": tags_mode,
+        "tagsMode": tags_mode,
         "includeTagColumns": tag_groups,
         "sqlWhereClause": sql_where_clause,
         "topCount": top_count,
@@ -249,6 +249,10 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
     df : pandas.DataFrame
 
     """
+    if (include_tag_groups is True or type(include_tag_groups) == list) and (include_metadata_keys is True or type(include_metadata_keys) == list):
+        logger.exception('Tags and Metadata cannot be returned in a single call. Please set either include_tag_groups or include_metadata_keys to False. ')
+        return
+
     if top_count is None:
         top_count = 0
 
