@@ -285,7 +285,7 @@ def upsert_sites(df: pandas.DataFrame, api_inputs: ApiInputs, tag_columns: list
         return response_status, pandas.DataFrame()
 
     if save_additional_columns_as_slices and slices_data_frame.shape[0] > 0:
-        print('Doing Slices: ' + str(save_additional_columns_as_slices) + ' - ' + str(slices_data_frame.shape[0]))
+        # print('Doing Slices: ' + str(save_additional_columns_as_slices) + ' - ' + str(slices_data_frame.shape[0]))
         slices_merged = pandas.merge(left=response_data_frame, right=slices_data_frame, left_on='installationCode',
                                      right_on='InstallationCode')
         slices_data_frame = slices_merged[['installationId', 'Slices']]
@@ -396,7 +396,7 @@ def upsert_workorders(df: pandas.DataFrame, api_inputs: ApiInputs, save_addition
         _work_order_schema.validate(data_frame, lazy=True)
     except pandera.errors.SchemaErrors as err:
         logger.error('Errors present with columns in df provided.')
-        print(err.failure_cases)
+        logger.error(err.failure_cases)
         schema_error = err.failure_cases
         return schema_error
 
@@ -506,11 +506,6 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
     req_cols = ', '.join(required_columns)
     proposed_columns = data_frame.columns.tolist()
 
-    # timeseries_intersect = list(set(required_columns) & set(proposed_columns))
-    # if len(timeseries_intersect) != 4:
-    #     logger.error("data_frame must contain the following columns: %s.", req_cols)
-    #     return 'Integration.upsert_timeseries(): data_frame must contain the following columns: ' + req_cols
-
     if not set(required_columns).issubset(proposed_columns):
         logger.exception('Missing required column(s): %s', set(required_columns).difference(proposed_columns))
         return 'integration.upsert_timeseries_ds() - data_frame must contain the following columns: ' + req_cols
@@ -539,10 +534,10 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
         data_frame['DataFeedFileStatusId'] = '00000000-0000-0000-0000-000000000000'
 
     site_list = data_frame['InstallationId'].unique().tolist()
-    start_date = data_frame['Timestamp'].dt.date.unique().min()
-    end_date = data_frame['Timestamp'].dt.date.unique().max()
+    start_date = data_frame['Timestamp'].min(axis=0, skipna=True)
+    end_date = data_frame['Timestamp'].max(axis=0, skipna=True)
 
-    timezones = _timezone_offsets(api_inputs=api_inputs, date_from=start_date, date_to=end_date,
+    timezones = _timezone_offsets(api_inputs=api_inputs, date_from=start_date.date, date_to=end_date.date,
                                   installation_id_list=site_list)
     timezones['dateFrom'] = timezones['dateFrom'].apply(lambda x: pandas.to_datetime(x))
     timezones['dateTo'] = timezones['dateTo'].apply(lambda x: pandas.to_datetime(x))
@@ -749,7 +744,6 @@ def replace_data(data_frame, api_inputs: ApiInputs, table_name: str):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    # print("Switch: Replacing All Data for ... " + name)
     logger.info("Replacing all data for %s", table_name)
 
     # upload Blobs to folder
@@ -757,7 +751,7 @@ def replace_data(data_frame, api_inputs: ApiInputs, table_name: str):
                                 api_project_id=api_inputs.api_project_id, is_timeseries=False)
     json_payload = {"path": upload_result[0], "fileCount": upload_result[1], "operation": "replace",
                     "tableDef": _get_structure(data_frame)}
-    print(json_payload)
+    logger.info(json_payload)
     url = api_prefix + api_inputs.datacentre + "/" + api_inputs.db_name + "/" + api_inputs.api_project_id + \
         "/AdxDataOperation/" + table_name
     logger.info("Sending request to ingest %s files from %s", str(upload_result[1]), upload_result[0])
@@ -772,7 +766,6 @@ def replace_data(data_frame, api_inputs: ApiInputs, table_name: str):
         logger.error('No data returned for this API call. %s', response.request.__dict__)
         return response_status
 
-    # print("         Done")
     logger.info("Ingestion complete. ")
 
     return response.text
@@ -809,7 +802,6 @@ def append_data(data_frame, api_inputs: ApiInputs, table_name: str):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    # print("Switch: Appending Data for ... " + name)
     logger.info("Appending data for %s", table_name)
 
     # upload Blobs to folder
